@@ -6,8 +6,7 @@ use crate::{
 };
 use is_macro::Is;
 use swc_atoms::JsWord;
-use swc_common::EqIgnoreSpan;
-use swc_common::{ast_node, Span};
+use swc_common::{ast_node, EqIgnoreSpan, Span};
 
 /// Used for `obj` property of `JSXMemberExpr`.
 #[ast_node]
